@@ -4,15 +4,16 @@ use warnings;
 
 package Perl::PrereqScanner;
 {
-  $Perl::PrereqScanner::VERSION = '1.012';
+  $Perl::PrereqScanner::VERSION = '1.019';
 }
-use Moose;
 # ABSTRACT: a tool to scan your Perl code for its prerequisites
 
+use Moose;
+
 use List::Util qw(max);
 use Params::Util qw(_CLASS);
 use Perl::PrereqScanner::Scanner;
-use PPI 1.205; # module_version
+use PPI 1.215; # module_version, bug fixes
 use String::RewritePrefix 0.005 rewrite => {
   -as => '__rewrite_scanner',
   prefixes => { '' => 'Perl::PrereqScanner::Scanner::', '=' => '' },
@@ -46,7 +47,7 @@ sub __prepare_scanners {
 sub BUILD {
   my ($self, $arg) = @_;
 
-  my @scanners = @{ $arg->{scanners} || [ qw(Perl5 TestMore Moose Aliased POE) ] };
+  my @scanners = @{ $arg->{scanners} || [ qw(Perl5 Superclass TestMore Moose Aliased POE) ] };
   my @extra_scanners = @{ $arg->{extra_scanners} || [] };
 
   my $scanners = $self->__prepare_scanners([ @scanners, @extra_scanners ]);
@@ -58,23 +59,22 @@ sub BUILD {
 sub scan_string {
   my ($self, $str) = @_;
   my $ppi = PPI::Document->new( \$str );
-  confess "PPI parse failed" unless defined $ppi;
+  confess "PPI parse failed: " . PPI::Document->errstr unless defined $ppi;
 
   return $self->scan_ppi_document( $ppi );
 }
 
 
-
 sub scan_file {
   my ($self, $path) = @_;
   my $ppi = PPI::Document->new( $path );
-  confess "PPI failed to parse '$path'" unless defined $ppi;
+  confess "PPI failed to parse '$path': " . PPI::Document->errstr
+      unless defined $ppi;
 
   return $self->scan_ppi_document( $ppi );
 }
 
 
-
 sub scan_ppi_document {
   my ($self, $ppi_doc) = @_;
 
@@ -87,18 +87,34 @@ sub scan_ppi_document {
   return $req;
 }
 
+
+sub scan_module {
+  my ($self, $module_name) = @_;
+
+  # consider rewriting to use Module::Which -- rjbs, 2013-11-03
+  require Module::Path;
+  if (defined(my $path = Module::Path::module_path($module_name))) {
+    return $self->scan_file($path);
+  }
+
+  confess "Failed to find file for module '$module_name'";
+}
+
 1;
 
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Perl::PrereqScanner - a tool to scan your Perl code for its prerequisites
 
 =head1 VERSION
 
-version 1.012
+version 1.019
 
 =head1 SYNOPSIS
 
@@ -107,6 +123,7 @@ version 1.012
   my $prereqs = $scanner->scan_ppi_document( $ppi_doc );
   my $prereqs = $scanner->scan_file( $file_path );
   my $prereqs = $scanner->scan_string( $perl_code );
+  my $prereqs = $scanner->scan_module( $module_name );
 
 =head1 DESCRIPTION
 
@@ -164,6 +181,10 @@ CPAN::Meta::Requirements object describing the modules it requires.
 
 This method will throw an exception if PPI fails to parse the code.
 
+B<Warning!>  It isn't entirely clear whether PPI prefers to receive
+strings as octet strings or character strings.  For now, my advice
+is to pass octet strings.
+
 =head2 scan_file
 
   my $prereqs = $scanner->scan_file( $path );
@@ -180,8 +201,20 @@ This method will throw an exception if PPI fails to parse the code.
 Given a L<PPI::Document>, this method returns a CPAN::Meta::Requirements object
 describing the modules it requires.
 
+=head2 scan_module
+
+  my $prereqs = $scanner->scan_module( $module_name );
+
+Given the name of a module, eg C<'PPI::Document'>,
+this method returns a CPAN::Meta::Requirements object
+describing the modules it requires.
+
 =for Pod::Coverage::TrustPod new
 
+=head1 SEE ALSO
+
+L<scan-perl-prereqs>, in this distribution, is a command-line interface to the scanner
+
 =head1 AUTHORS
 
 =over 4
@@ -204,7 +237,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
